@@ -138,12 +138,18 @@ class tables(str, Enum):
 
 async def aiter(list: List):
     for i in list:
+        if isinstance(i, bytes):
+            yield i.decode("utf-8").replace("\\n", "\\\\n").replace(
+                "\\t", "\\\\t"
+            ).encode("utf-8")
         if isinstance(i, str):
-            yield i.replace("\\n", "\\\\n").replace("\\t", "\\\\t")
+            yield i.replace("\\n", "\\\\n").replace("\\t", "\\\\t").encode(
+                "utf-8"
+            )
         else:
             yield orjson.dumps(i, option=orjson.OPT_APPEND_NEWLINE).decode(
                 "utf-8"
-            ).replace("\\n", "\\\\n").replace("\\t", "\\\\t")
+            ).replace("\\n", "\\\\n").replace("\\t", "\\\\t").encode("utf-8")
 
 
 async def copy(iter, table: tables, conn: asyncpg.Connection):
